@@ -5,17 +5,18 @@ from plotex.utils import set_text
 
 
 def column_frequency(ax, df, column, cmap=None, percent=True, **piekwargs):
-    """
-    create a pie chart based on the frequency of values in a particular column
+    """create a pie chart based on the frequency of values in a particular column
 
-    :param ax: matplotlib axis object
-    :param df: the dataframe with the data 
-    :param column: the column to calculate frequencies over 
-    :param cmap: the colormap to use, defaults to None
-    :param percent: whether to display percentages, defaults to True
-    :param piekwargs: keyword arguments to pass into the pie function
-    
-    :return ax: the axis object
+    Args:
+        ax: matplotlib axis object
+        df: the dataframe with the data
+        column: the column to calculate frequencies over
+        cmap: the colormap to use, defaults to None
+        percent: whether to display percentages, defaults to True
+        **piekwargs: keyword arguments to pass into the pie function
+
+    Returns:
+        `ax`, the axis object
     """
     value_counts = df[column].value_counts()
     
